@@ -5,7 +5,7 @@
 '''
 
 import os
-from fasttest.common.log import log_error
+from aumtest.common.log import log_error
 
 class TestCaseUtils(object):
 
